@@ -24,7 +24,6 @@ install_reqs = [
     'diskcache',
     'requests>=2.4.2',
     'requests_toolbelt',
-    'six'
 ]
 with open('README.rst') as f:
     readme = f.read()
@@ -45,7 +44,6 @@ setup(
         'Environment :: Console',
         'License :: OSI Approved :: Apache Software License',
         'Operating System :: OS Independent',
-        'Programming Language :: Python :: 2',
         'Programming Language :: Python :: 3'
     ],
     packages=find_packages(exclude=('tests.*', 'tests')),
