@@ -37,10 +37,6 @@ _girder_imports |= {
     'requests_toolbelt',
     'yaml'
 }
-# The funcsigs package (only used in Python2) is necessary to ensure import-time logic in girder
-# executes correctly. For some reason (which doesn't apply to six), mocking it interferes with its
-# import, even if it's installed.
-_girder_imports.discard('funcsigs')
 
 # Set Sphinx variables
 master_doc = 'index'
@@ -63,14 +59,12 @@ extensions = [
     'sphinx.ext.autodoc',
     'sphinx.ext.intersphinx',
     'sphinx.ext.viewcode',
-    'sphinx_tabs.tabs'
 ]
 
 autodoc_mock_imports = list(_girder_imports)
 
 intersphinx_mapping = {
     'python': ('https://docs.python.org/3', None),
-    'pymongo': ('https://api.mongodb.com/python/current/', None)
 }
 
 
@@ -85,7 +79,7 @@ class PatchedPythonDomain(PythonDomain):
         if target == 'list':
             # References to built-in symbols natively return None
             return None
-        return super(PatchedPythonDomain, self).resolve_xref(
+        return super().resolve_xref(
             env, fromdocname, builder, typ, target, node, contnode)
 
 
