@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 import bson.json_util
 import dateutil.parser
+from functools import wraps
 import inspect
 import jsonschema
 import os
-import six
 import cherrypy
 from collections import OrderedDict
 
@@ -21,15 +21,12 @@ from girder.utility.resource import _apiRouteMap
 from . import docs, access
 from .rest import Resource, getApiUrl, getUrlParts
 
-if six.PY3:
-    from inspect import signature, Parameter
-else:
-    from funcsigs import signature, Parameter
+from inspect import signature, Parameter
 
 SWAGGER_VERSION = '2.0'
 
 
-class Description(object):
+class Description:
     """
     This class provides convenient chainable semantics to allow api route
     handlers to describe themselves to the documentation. A route handler
@@ -330,7 +327,7 @@ class Description(object):
             that were passed.
         :type schema: dict
         """
-        if default:
+        if default is not None and default != ():
             default = bson.json_util.dumps(default)
 
         self.param(
@@ -403,7 +400,7 @@ class Description(object):
 
         # Combine list of reasons into a single string.
         # swagger-ui renders the description using Markdown.
-        if not isinstance(reason, six.string_types):
+        if not isinstance(reason, str):
             reason = '\n\n'.join(reason)
 
         if code in self._responses:
@@ -436,7 +433,7 @@ class ApiDocs(WebrootBase):
         if not templatePath:
             templatePath = os.path.join(constants.PACKAGE_DIR,
                                         'api', 'api_docs.mako')
-        super(ApiDocs, self).__init__(templatePath)
+        super().__init__(templatePath)
 
         curConfig = config.getConfig()
         self.vars['mode'] = curConfig['server'].get('mode', '')
@@ -446,12 +443,12 @@ class ApiDocs(WebrootBase):
         self.vars['apiRoot'] = server.getApiRoot()
         self.vars['staticPublicPath'] = server.getStaticPublicPath()
         self.vars['brandName'] = Setting().get(SettingKey.BRAND_NAME)
-        return super(ApiDocs, self)._renderHTML()
+        return super()._renderHTML()
 
 
 class Describe(Resource):
     def __init__(self):
-        super(Describe, self).__init__()
+        super().__init__()
         self.route('GET', (), self.listResources, nodoc=True)
 
     @access.public
@@ -467,10 +464,10 @@ class Describe(Resource):
 
         routeMap = _apiRouteMap()
 
-        for resource in sorted(six.viewkeys(docs.routes), key=str):
+        for resource in sorted(docs.routes.keys(), key=str):
             # Update Definitions Object
             if resource in docs.models:
-                for name, model in six.viewitems(docs.models[resource]):
+                for name, model in docs.models[resource].items():
                     definitions[name] = model
 
             prefixPath = None
@@ -486,10 +483,10 @@ class Describe(Resource):
                 'name': tag
             })
 
-            for route, methods in six.viewitems(docs.routes[resource]):
+            for route, methods in docs.routes[resource].items():
                 # Path Item Object
                 pathItem = {}
-                for method, operation in six.viewitems(methods):
+                for method, operation in methods.items():
                     # Operation Object
                     pathItem[method.lower()] = operation
                     if prefixPath:
@@ -519,7 +516,7 @@ class Describe(Resource):
         }
 
 
-class describeRoute(object):  # noqa: class name
+class describeRoute:  # noqa: class name
     def __init__(self, description):
         """
         This returns a decorator to set the API documentation on a route
@@ -556,7 +553,7 @@ class autoDescribeRoute(describeRoute):  # noqa: class name
         :param hide: Set to True if this route should not appear in the swagger listing.
         :type hide: bool
         """
-        super(autoDescribeRoute, self).__init__(description=description)
+        super().__init__(description=description)
         self.hide = hide
 
     def _passArg(self, fun, kwargs, name, val):
@@ -596,7 +593,7 @@ class autoDescribeRoute(describeRoute):  # noqa: class name
     def _inspectFunSignature(self, fun):
         self._funNamedArgs = set()
         self._funHasKwargs = False
-        for funParam in six.viewvalues(signature(fun).parameters):
+        for funParam in signature(fun).parameters.values():
             if funParam.kind in {Parameter.POSITIONAL_OR_KEYWORD, Parameter.KEYWORD_ONLY}:
                 # POSITIONAL_OR_KEYWORD are basic positional parameters
                 # KEYWORD_ONLY are named parameters that appear after a * in Python 3
@@ -619,14 +616,14 @@ class autoDescribeRoute(describeRoute):  # noqa: class name
     def __call__(self, fun):
         self._inspectFunSignature(fun)
 
-        @six.wraps(fun)
+        @wraps(fun)
         def wrapped(*args, **kwargs):
             """
             Transform any passed params according to the spec, or
             fill in default values for any params not passed.
             """
             # Combine path params with form/query params into a single lookup table
-            params = {k: v for k, v in six.viewitems(kwargs) if k != 'params'}
+            params = {k: v for k, v in kwargs.items() if k != 'params'}
             params.update(kwargs.get('params', {}))
 
             kwargs['params'] = kwargs.get('params', {})
