@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 import cherrypy
 import errno
-import six
 
 from ..describe import Description, autoDescribeRoute, describeRoute
 from ..rest import Resource, filtermodel
@@ -24,7 +23,7 @@ class File(Resource):
     """
 
     def __init__(self):
-        super(File, self).__init__()
+        super().__init__()
         self._model = FileModel()
 
         self.resourceName = 'file'
@@ -181,7 +180,7 @@ class File(Resource):
         """
         offset = Upload().requestOffset(upload)
 
-        if isinstance(offset, six.integer_types):
+        if isinstance(offset, int):
             upload['received'] = offset
             Upload().save(upload)
             return {'offset': offset}
