@@ -4,12 +4,11 @@ This module defines functions for registering, loading, and querying girder plug
 
 import distutils.dist
 from functools import wraps
+import io
 import json
 import os
 from pkg_resources import iter_entry_points, resource_filename
 
-import six
-
 from girder import logprint
 from girder.exceptions import GirderException
 
@@ -67,8 +66,7 @@ class _PluginMeta(type):
         return wrapper
 
 
-@six.add_metaclass(_PluginMeta)
-class GirderPlugin(object):
+class GirderPlugin(metaclass=_PluginMeta):
     """
     This is a base class for describing a girder plugin.  A plugin is registered by adding
     an entrypoint under the namespace ``girder.plugin``.  This entrypoint should return a
@@ -161,7 +159,7 @@ def _readPackageMetadata(distribution):
     """Get a metadata object associated with a python package."""
     metadata_string = distribution.get_metadata(distribution.PKG_INFO)
     metadata = distutils.dist.DistributionMetadata()
-    metadata.read_pkg_file(six.StringIO(metadata_string))
+    metadata.read_pkg_file(io.StringIO(metadata_string))
     return metadata
 
 
