@@ -16,7 +16,6 @@ Example of creating and consuming a streaming zip:
 
 import binascii
 import os
-import six
 import struct
 import sys
 import time
@@ -35,7 +34,7 @@ STORE = 0
 DEFLATE = 8
 
 
-class ZipInfo(object):
+class ZipInfo:
 
     __slots__ = (
         'filename',
@@ -56,7 +55,7 @@ class ZipInfo(object):
         # names are used as tricks by viruses in archives.
         if os.sep != '/' and os.sep in filename:
             filename = filename.replace(os.sep, '/')
-        if isinstance(filename, six.text_type):
+        if isinstance(filename, str):
             filename = filename.encode('utf8')
         # Escaping or locale conversion should go here
         nullByte = filename.find(b'\x00')
@@ -95,7 +94,7 @@ class ZipInfo(object):
         return header + self.filename
 
 
-class ZipGenerator(object):
+class ZipGenerator:
     """
     This class can be used to create a streaming zip file that consumes from
     one generator and writes to another.
@@ -153,7 +152,7 @@ class ZipGenerator(object):
         for buf in generator():
             if not buf:
                 break
-            if isinstance(buf, six.text_type):
+            if isinstance(buf, str):
                 buf = buf.encode('utf8')
             fileSize += len(buf)
             if self.useCRC:
